//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[YakuSerializer](index.md)/[deserialize](deserialize.md)

# deserialize

[common]\
open override fun [deserialize](deserialize.md)(decoder: Decoder): [Yaku](../-yaku/index.md)
